import QtQuick 2.9
import QtQuick.Controls 2.2
import QtQuick.Controls.Styles 1.4
import QtQuick.Extras 1.4
import QtQuick.Extras.Private 1.0
import QtQuick.Layouts 1.3
import QtQuick.Controls.Material 2.2
import QtGraphicalEffects 1.0

Item {
    id: batery
    width: 300
    height: 300

    property alias value: gauge.value
    property alias maximumValue: gauge.maximumValue
    property alias minimumValue: gauge.minimumValue

    property string unitGaugeText: "%"
    property string gaugeText: "Batery Level"
    property int size: (width < height) ? width : height
    property int borderSize: 0

    property string fontName: "Sans Serif"

    property color backgroundColor: "#000000"
    property color textColor: "#F5F5F5"
    property color foregroundColor: "#000000"
    property color foregroundColorLight: "#00c853"

    // ARREGLAR ESTOS
    property int tickmarkStepSize1: 10
    property int minAngleValue: -145
    property int maxAngleValue: 145
    property double backgroundLineWidth: 0.1   // value range [0,1]
    property double foregroundLineWidth: 0.1   // value range [0,1]

    Item {
        id: container
        anchors.centerIn: parent
        width:  rect.width  + 10+(2 * shadow.radius)
        height: rect.height + 10+(2 * shadow.radius)
        visible: false

        Rectangle {
            id: rect
            gradient: Gradient{
                GradientStop { position: 0; color:(gauge.value<speedometer.maximumValue/10)? "#442121":
                                                  (gauge.value<speedometer.maximumValue/4)? "#333321":"#214421" }
                GradientStop { position: 1; color: "#353535" }
                GradientStop { position: 2; color: "#555555" }
            }

            anchors.centerIn: parent
            width: size
            height: size
            radius: width*0.5
            Material.elevation: 20
            border.width: (borderSize === 0) ? 5 : borderSize
            border.color: (borderSize === 0) ? "#00000000" : backgroundColor

            CircularGauge {
                id: gauge
                anchors.centerIn: parent
                width: (borderSize === 0) ? size : size - borderSize
                height: (borderSize === 0) ? size : size - borderSize
                //width: size
                //height: size
                maximumValue: speedometer.maximumValue
                minimumValue: speedometer.minimumValue
                Behavior on value {
                    NumberAnimation {
                        duration: 1000
                    }
                }

                ColumnLayout {
                    anchors.centerIn: parent
                    Text {
                        Layout.alignment: Qt.AlignCenter
                        color: textColor
                        font.pointSize: (0.12*size)
                        text: (gauge.value).toFixed() + unitGaugeText
                        font.family: fontName
                    }
                    Text {
                        Layout.alignment: Qt.AlignCenter
                        color: textColor
                        font.pointSize: (0.05*size)
                        text: gaugeText
                        font.family: fontName
                    }
                }

                style: CircularGaugeStyle {
                    id: style

                    maximumValueAngle: maxAngleValue
                    minimumValueAngle: minAngleValue

                    function degreesToRadians(degrees) {
                        return degrees * (Math.PI / 180);
                    }

                    tickmarkLabel:  Rectangle {
                        visible: false
                    }

                    tickmarkStepSize: tickmarkStepSize1

                    tickmark: Rectangle {
                        visible: false
                    }

                    minorTickmark: Rectangle {
                        visible: false
                    }

                    needle: Rectangle {
                        visible: false
                    }

                    background: Canvas {

                        onPaint: {
                            var ctx = getContext("2d");
                            ctx.reset();

                            ctx.beginPath();
                            ctx.strokeStyle = foregroundColor;
                            ctx.lineWidth = outerRadius * backgroundLineWidth;

                            ctx.arc(outerRadius, outerRadius, outerRadius - ctx.lineWidth / 2,
                                degreesToRadians(valueToAngle(0) - 90), degreesToRadians(valueToAngle(gauge.maximumValue) - 90));
                            ctx.stroke();
                        }

                    }

                    foreground: Canvas {
                        id: canvas

                        onPaint: {
                            var ctx = getContext("2d");
                            ctx.reset();

                            ctx.beginPath();
                            ctx.strokeStyle = foregroundColorLight;
                            ctx.lineWidth = outerRadius * foregroundLineWidth;

                            ctx.arc(outerRadius, outerRadius, outerRadius - ctx.lineWidth / 2,
                                degreesToRadians(valueToAngle(0) - 90), degreesToRadians(valueToAngle(gauge.value) - 90));
                            ctx.stroke();
                        }

                        Connections {
                            target: gauge
                            onValueChanged: canvas.requestPaint();
                        }

                    }
                }
            }
        }
    }

    DropShadow {
        id: shadow
        anchors.fill: source
        cached: true
        horizontalOffset: 0
        verticalOffset: 0
        radius: 10.0
        samples: 16
        color: "#80000000"
        smooth: true
        source: container
    }
}
