#ifndef BACKEND_H
#define BACKEND_H
#include "canbus.h"

class BackEnd : public CanBus
{
    Q_OBJECT


    Q_PROPERTY(float voltage READ voltage WRITE setVoltage NOTIFY voltageChanged)
    Q_PROPERTY(float current READ current WRITE setCurrent NOTIFY currentChanged)
    Q_PROPERTY(float battery READ battery WRITE setBattery NOTIFY batteryChanged)
    Q_PROPERTY(float  temp READ temp WRITE setTemp NOTIFY tempChanged)
    Q_PROPERTY(float humidity READ humidity WRITE setHumidity NOTIFY humidityChanged)
    Q_PROPERTY(float  height READ height WRITE setHeight NOTIFY heightChanged)
    Q_PROPERTY(float  pressure READ pressure WRITE setPressure NOTIFY pressureChanged)
    Q_PROPERTY(float velocity READ velocity WRITE setVelocity NOTIFY velocityChanged)
    Q_PROPERTY(float rpm READ rpm WRITE setRpm NOTIFY rpmChanged)


public:
    explicit BackEnd(QObject *parent = nullptr);

    float voltage();
    float current();
    float battery();
    float temp();
    float humidity();
    float height();
    float pressure();
    float velocity();
    float rpm();
    void setVoltage(float voltage);
    void setCurrent(float current);
    void setBattery(float battery);
    void setTemp(float temp);
    void setHumidity(float humidity);
    void setHeight(float height);
    void setPressure(float pressure);
    void setVelocity(float velocity);
    void setRpm(float rpm);
    Q_INVOKABLE QString printFrame();

private:

    float _voltage;
    float _current;
    float _battery;
    float _temp;
    float _humidity;
    float _height;
    float _pressure;
    float _velocity;
    float _rpm;
signals:
    void voltageChanged();
    void velocityChanged();
    void rpmChanged();
    void currentChanged();
    void batteryChanged();
    void tempChanged();
    void humidityChanged();
    void heightChanged();
    void pressureChanged();
    void framesReceived();

    void rpmCritical();
    void velocityMax();
    void voltageWrong();
    void criticalBattery();
    void currentExceed();
    void tempExceed();
    void humidityExceed();
    void pressureExceed();
    void heightExceed();

public slots:
    void readData();
};

#endif // BACKEND_H
